# AI Agent Discovery
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/ai-agent-discovery#overview)
  * [Benefits](https://help.sap.com/docs/leanix/ea/ai-agent-discovery#benefits)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/ai-agent-discovery#prerequisites)
  * [Available Integrations](https://help.sap.com/docs/leanix/ea/ai-agent-discovery#available-integrations)
  * [AI Agent Discovery Inbox](https://help.sap.com/docs/leanix/ea/ai-agent-discovery#ai-agent-discovery-inbox)
  * [Getting Started with AI Agent Discovery](https://help.sap.com/docs/leanix/ea/ai-agent-discovery#getting-started-with-ai-agent-discovery)


Discover AI agents and MCP servers by setting up integrations with agent-building platforms and registry systems. Review discovered items in the AI agent discovery inbox and add relevant ones to your inventory.
